@@ -1,27 +1,28 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: path
-version: 0.5.3
-id: path-0.5.3-729f9970947dead951cc1e0658c28bff
-key: path_BuFcQg3iwex0MNhLAdsJ0E
+version: 0.5.7
+id: path-0.5.7-793cc30d1691cb7d9fba07f28c69fc6d
+key: path_CFTaKMp26AIF9HrGATCehR
 license: BSD3
-copyright: 2015 FP Complete
-maintainer: chrisdone@fpcomplete.com
-synopsis: Path
+copyright: 2015–2016 FP Complete
+maintainer: Chris Done <chrisdone@fpcomplete.com>
+synopsis: Support for well-typed paths
 description:
-    Path
+    Support for will-typed paths.
 category: Filesystem
-author: Chris Done
+author: Chris Done <chrisdone@fpcomplete.com>
 exposed: True
 exposed-modules:
     Path Path.Internal
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/path-0.5.3
-library-dirs: /usr/lib/ghc-7.10.3/site-local/path-0.5.3
-data-dir: /usr/share/arm-linux-ghc-7.10.3/path-0.5.3
-hs-libraries: HSpath-0.5.3-BuFcQg3iwex0MNhLAdsJ0E
+import-dirs: /usr/lib/ghc-7.10.3/site-local/path-0.5.7
+library-dirs: /usr/lib/ghc-7.10.3/site-local/path-0.5.7
+data-dir: /usr/share/arm-linux-ghc-7.10.3/path-0.5.7
+hs-libraries: HSpath-0.5.7-CFTaKMp26AIF9HrGATCehR
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
+    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
